import { Accessor, Resource } from 'solid-js';

export declare function when<T, const TAccessor extends Accessor<T> | T, const TValues extends TAccessor extends ((...args: any[]) => any) | undefined ? Exclude<ReturnType<Exclude<TAccessor, undefined>>, null | undefined | false> : Exclude<TAccessor, null | undefined | false>, const TResult>(accessor: TAccessor, callback: (value: TValues) => TResult): TResult | undefined;
export declare function when<T, const TAccessor extends Accessor<T> | T, const TValues extends TAccessor extends ((...args: any[]) => any) | undefined ? Exclude<ReturnType<Exclude<TAccessor, undefined>>, null | undefined | false> : Exclude<TAccessor, null | undefined | false>, const TResult, const TFallbackResult>(accessor: TAccessor, callback: (value: TValues) => TResult, fallback: () => TFallbackResult): TResult | TFallbackResult;
/**
 * Returns a function that conditionally executes a callback based on the truthiness of an accessor's value,
 * suitable for use in reactive programming contexts.
 * @param accessor The value or function returning a value that is checked for truthiness.
 * @param callback The callback function to be executed if the accessor's value is truthy.
 * @returns A function that can be called to execute the callback conditionally based on the accessor's value.
 */
export declare function whenever<T, const TAccessor extends Accessor<T> | T, const TValues extends TAccessor extends ((...args: any[]) => any) | undefined ? Exclude<ReturnType<Exclude<TAccessor, undefined>>, null | undefined | false> : Exclude<TAccessor, null | undefined | false>, const TResult>(accessor: TAccessor, callback: (value: TValues) => TResult): () => TResult | undefined;
export declare function whenever<const T, const TAccessor extends Accessor<T> | T, const TValues extends TAccessor extends ((...args: any[]) => any) | undefined ? Exclude<ReturnType<Exclude<TAccessor, undefined>>, null | undefined | false> : Exclude<TAccessor, null | undefined | false>, const TResult, const TFallbackResult>(accessor: TAccessor, callback: (value: TValues) => TResult, fallback: () => TFallbackResult): () => TResult | TFallbackResult;
/**
 * Returns a function that conditionally executes and aggregates results from multiple accessors if all values are truthy.
 *
 * @param accessors Multiple accessors to be checked for truthiness.
 * @returns A function that can be called to conditionally execute based on the truthiness of all accessor values, returning their results as an array or undefined if any are not truthy.
 */
export declare function every<const T, TAccessors extends Array<Accessor<T> | T>, const TValues extends {
    [TKey in keyof TAccessors]: TAccessors[TKey] extends ((...args: any[]) => any) | undefined ? Exclude<ReturnType<Exclude<TAccessors[TKey], undefined>>, null | undefined | false> : Exclude<TAccessors[TKey], null | undefined | false>;
}>(...accessors: TAccessors): () => TValues | undefined;
export declare function wrapNullableResource<T extends Resource<any>>(value: T): Accessor<false | [ReturnType<T>]>;
